@@ -2,6 +2,8 @@
 # -*- coding: utf-8 -*-
 """This module corresponds to the photoobj directory in photoop.
 """
+import numpy as np
+import astropy.units as u
 
 
 def sdss_calibv():
@@ -9,7 +11,7 @@ def sdss_calibv():
 
     Returns
     -------
-    :class:`float`
+    :class:`~astropy.units.quanity.Quantity`
         The conversion from pixels per frame to degrees per day
 
     Notes
@@ -19,10 +21,9 @@ def sdss_calibv():
     sky from adjacent bands are separated by *two* frame numbers,
     so we multiply by a factor two.
     """
-    pixscale = 0.396   # arcsec
-    ftime = 71.72    # seconds
-    pixframe2degday = 2.0*pixscale/(3600.0) * (3600.0)*24.0/ftime
-    return pixframe2degday
+    pixscale = 0.396 * u.arcsec
+    ftime = 71.72 * u.s
+    return (2.0*pixscale/ftime).to('deg / d')
 
 
 def unwrap_objid(objid):
@@ -40,8 +41,13 @@ def unwrap_objid(objid):
     Returns
     -------
     :class:`numpy.recarray`
-        A record array with the same length as objid, with the columns
-        'run', 'camcol', 'frame', 'id', 'rerun', 'skyversion'.
+        A record array with the same length as `objid`, with the columns
+        'skyversion', 'rerun', 'run', 'camcol', 'firstfield', 'frame', 'id'.
+
+    Raises
+    ------
+    :exc:`ValueError`
+        If the input objID has a type that can't be converted into 64-bit integer.
 
     Notes
     -----
@@ -57,11 +63,16 @@ def unwrap_objid(objid):
     >>> from numpy import array
     >>> from pydl.photoop.photoobj import unwrap_objid
     >>> unwrap_objid(array([1237661382772195474]))
-    rec.array([(2, 301, 3704, 3, 91, 146)],
-          dtype=[('skyversion', '<i4'), ('rerun', '<i4'), ('run', '<i4'), ('camcol', '<i4'), ('frame', '<i4'), ('id', '<i4')])
+    rec.array([(2, 301, 3704, 3, 0, 91, 146)],
+          dtype=[('skyversion', '<i4'), ('rerun', '<i4'), ('run', '<i4'), ('camcol', '<i4'), ('firstfield', '<i4'), ('frame', '<i4'), ('id', '<i4')])
     """
-    import numpy as np
-    if objid.dtype.type is np.string_ or objid.dtype.type is np.unicode_:
+    try:
+        np_string = np.string_  # Numpy 1.x
+        np_unicode = np.unicode_
+    except AttributeError:
+        np_string = np.bytes_  # Numpy 2.x
+        np_unicode = np.str_
+    if objid.dtype.type is np_string or objid.dtype.type is np_unicode:
         tempobjid = objid.astype(np.int64)
     elif objid.dtype.type is np.int64:
         tempobjid = objid.copy()
@@ -70,12 +81,13 @@ def unwrap_objid(objid):
     unwrap = np.recarray(objid.shape,
                          dtype=[('skyversion', 'i4'), ('rerun', 'i4'),
                                 ('run', 'i4'), ('camcol', 'i4'),
+                                ('firstfield', 'i4'),
                                 ('frame', 'i4'), ('id', 'i4')])
     unwrap.skyversion = np.bitwise_and(tempobjid >> 59, 2**4 - 1)
     unwrap.rerun = np.bitwise_and(tempobjid >> 48, 2**11 - 1)
     unwrap.run = np.bitwise_and(tempobjid >> 32, 2**16 - 1)
     unwrap.camcol = np.bitwise_and(tempobjid >> 29, 2**3 - 1)
-    # unwrap.firstfield = np.bitwise_and(tempobjid >> 28, 2**1 - 1)
+    unwrap.firstfield = np.bitwise_and(tempobjid >> 28, 2**1 - 1)
     unwrap.frame = np.bitwise_and(tempobjid >> 16, 2**12 - 1)
     unwrap.id = np.bitwise_and(tempobjid, 2**16 - 1)
     return unwrap
