@@ -8,19 +8,23 @@ from warnings import warn
 import numpy as np
 from astropy import log
 from astropy.io import fits
+from astropy.io.fits.fitsrec import FITS_rec
+from astropy.table import Table
 from . import PhotoopException
 from .sdssio import sdss_name, sdss_calib
-from ..pydlutils.mangle import set_use_caps
+from ..pydlutils.mangle import FITS_polygon
 from ..pydlutils.sdss import sdss_flagval
 
 
-def sdss_score(flist, silent=True):
+def sdss_score(flist, silent=True, **kwargs):
     """Score a list of imaging fields from zero to one.
 
+    Additional keyword arguments are passed to :func:`~pydl.photoop.sdssio.sdss_calib`.
+
     Parameters
     ----------
     flist : :class:`~astropy.io.fits.HDUList`
-        Opened FITS file.
+        Opened FITS file, typically ``window_flist.fits``.
     silent : :class:`bool`, optional
         If ``False``, print extra information.
 
@@ -29,10 +33,13 @@ def sdss_score(flist, silent=True):
     :class:`numpy.ndarray`
         A vector of scores, one for each row of the FITS file.
     """
-    lat = 32.780361
-    lng = 360.0 - 105.820417
-    tzone = 7
-    scores = 1
+    #
+    # Not sure why these were defined.
+    #
+    # lat = 32.780361
+    # lng = 360.0 - 105.820417
+    # tzone = 7
+    # scores = 1
     #
     # Read the PHOTO status bits
     #
@@ -162,76 +169,112 @@ def sdss_score(flist, silent=True):
     return fdata.field('SCORE')
 
 
-def window_read(**kwargs):
-    """Read window files in $PHOTO_RESOLVE.
+def window_read(flist=False, rescore=False, blist=False, bcaps=False,
+                balkans=False, findx=False, bindx=False):
+    """Read window files in :envvar:`PHOTO_RESOLVE`.
+
+    Parameters
+    ----------
+    flist : :class:`bool`, optional
+        If ``True``, read the ``window_flist.fits`` file.
+    rescore : :class:`bool`, optional
+        If `flist` is ``True``, look for ``window_flist_rescore.fits``, and run
+        :func:`~pydl.photoop.window.window_score` if it is not found.
+    blist : :class:`bool`, optional
+        If ``True``, read the ``window_blist.fits`` file.
+    bcaps : :class:`bool`, optional
+        If ``True``, read the ``window_bcaps.fits`` file.
+    balkans : :class:`bool`, optional
+        If ``True``, construct the balkans from the ``window_blist.fits`` and
+        ``window_bcaps.fits`` files.
+    findx : :class:`bool`, optional
+        If ``True``, read the ``window_findx.fits`` file.
+    bindx : :class:`bool`, optional
+        If ``True``, read the ``window_bindx.fits`` file.
+
+    Returns
+    -------
+    :class:`dict`
+        A dictionary containing the requested window data.
+
+    Notes
+    -----
+    If `balkans` is ``True``, the balkans data will be in the form of a
+    :class:`~pydl.pydlutils.mangle.FITS_polygon` object, to facilitate
+    interoperability with :mod:`pydl.pydlutils.mangle`.  In this object,
+    the keyword ``IFIELD`` is equivalent to ``IPRIMARY`` and ``PIXEL`` is
+    eqivalent to ``IBINDX``.
     """
     try:
         resolve_dir = os.environ['PHOTO_RESOLVE']
     except KeyError:
         raise PhotoopException(('You have not set the environment variable ' +
                                 'PHOTO_RESOLVE!'))
-    if 'silent' not in kwargs:
-        kwargs['silent'] = True
     r = dict()
-    if 'flist' in kwargs:
-        if 'rescore' in kwargs:
+    if flist:
+        flist_file = os.path.join(resolve_dir, 'window_flist.fits')
+        if rescore:
             flist_file = os.path.join(resolve_dir, 'window_flist_rescore.fits')
-            if not os.path.exists(rescore_file):
-                #
-                # This will be called if window_flist_rescore.fits doesn't exist.
-                #
-                window_score()
-        else:
-            flist_file = os.path.join(resolve_dir, 'window_flist.fits')
-        with fits.open(rescore_file) as fit:
-            r['flist'] = fit[1].data
-    if 'blist' in kwargs or 'balkans' in kwargs:
+            if not os.path.exists(flist_file):
+                window_score(rescore=rescore)
+        r['flist'] = Table.read(flist_file, hdu=1)
+    if blist or balkans:
         blist_file = os.path.join(resolve_dir, 'window_blist.fits')
-        with fits.open(balkan_file) as fit:
-            r['blist'] = fit[1].data
-    if 'bcaps' in kwargs or 'balkans' in kwargs:
+        r['blist'] = Table.read(blist_file, hdu=1)
+    if bcaps or balkans:
         bcaps_file = os.path.join(resolve_dir, 'window_bcaps.fits')
-        with fits.open(bcaps_file) as fit:
-            r['bcaps'] = fit[1].data
-    if 'findx' in kwargs:
+        r['bcaps'] = Table.read(bcaps_file, hdu=1)
+    if findx:
         findx_file = os.path.join(resolve_dir, 'window_findx.fits')
-        with fits.open(findx_file) as fit:
-            r['findx'] = fit[1].data
-    if 'bindx' in kwargs:
+        r['findx'] = Table.read(findx_file, hdu=1)
+    if bindx:
         bindx_file = os.path.join(resolve_dir, 'window_bindx.fits')
-        with fits.open(bindx_file) as fit:
-            r['bindx'] = fit[1].data
-    if 'balkans' in kwargs:
-        #
-        # Copy blist data to balkans
-        #
-        r['balkans'] = r['blist'].copy()
-        r['balkans']['caps'] = {'X': list(), 'CM': list()}
-        r['balkans']['use_caps'] = np.zeros(r['balkans']['ICAP'].shape,
-                                            dtype=np.uint64)
-        if 'blist' not in kwargs:
+        r['bindx'] = Table.read(bindx_file, hdu=1)
+    if balkans:
+        max_caps = r['blist']['NCAPS'].max()
+        r['balkans'] = np.recarray((len(r['blist']),),
+                                   dtype=[('IFIELD', r['blist']['IPRIMARY'].dtype),
+                                          ('PIXEL', r['blist']['IBINDX'].dtype),
+                                          ('NCAPS', r['blist']['NCAPS'].dtype),
+                                          ('USE_CAPS', np.int32),
+                                          ('WEIGHT', r['blist']['WEIGHT'].dtype),
+                                          ('STR', r['blist']['STR'].dtype),
+                                          ('XCAPS', r['bcaps']['X'].dtype, (max_caps, 3)),
+                                          ('CMCAPS', r['bcaps']['CM'].dtype, (max_caps,)),
+                                          ]).view(FITS_rec)
+        r['balkans']['IFIELD'] = r['blist']['IPRIMARY']
+        r['balkans']['PIXEL'] = r['blist']['IBINDX']
+        r['balkans']['NCAPS'] = r['blist']['NCAPS']
+        r['balkans']['USE_CAPS'] = (1 << r['blist']['NCAPS']) - 1
+        r['balkans']['WEIGHT'] = r['blist']['WEIGHT']
+        r['balkans']['STR'] = r['blist']['STR']
+        for k in range(len(r['blist'])):
+            r['balkans'][k]['XCAPS'][0:r['blist']['NCAPS'][k], :] = r['bcaps']['X'][r['blist']['ICAP'][k]:r['blist']['ICAP'][k]+r['blist']['NCAPS'][k], :]
+            r['balkans'][k]['CMCAPS'][0:r['blist']['NCAPS'][k]] = r['bcaps']['CM'][r['blist']['ICAP'][k]:r['blist']['ICAP'][k]+r['blist']['NCAPS'][k]]
+            #
+            # Since allow_doubles is True, would set_use_caps ever return anything but the default value?
+            # Comparing to the IDL code, it does appear to be the case that
+            # set_use_caps is completely useless.
+            #
+            # r['balkans'][k]['USE_CAPS'] = set_use_caps(ManglePolygon(r['balkans'][k]),
+            #                                            np.arange(r['balkans'][k]['NCAPS'], dtype=np.int32),
+            #                                            allow_doubles=True)
+        r['balkans'] = r['balkans'].view(FITS_polygon)
+        if not blist:
             del r['blist']
-        #
-        # Copy bcaps data into balkans
-        #
-        for k in range(len(r['balkans']['ICAP'])):
-            r['balkans']['caps']['X'].append(r['bcaps']['X'][balkans['ICAP'][k]:balkans['ICAP'][k]+balkans['NCAPS'][k]])
-            r['balkans']['caps']['CM'].append(r['bcaps']['CM'][balkans['ICAP'][k]:balkans['ICAP'][k]+balkans['NCAPS'][k]])
-            r['balkans']['use_caps'][k] = set_use_caps(
-                r['balkans']['caps']['X'][k],
-                r['balkans']['caps']['CM'][k],
-                r['balkans']['use_caps'][k],
-                allow_doubles=True)
-        if 'bcaps' not in kwargs:
+        if not bcaps:
             del r['bcaps']
     return r
 
 
-def window_score(**kwargs):
+def window_score(rescore=False):
     """For uber-resolve, score all the fields from zero to one.
 
-    If 'rescore' is set, then write a new file 'window_flist_rescore.fits'
-    rather than over-writing the file 'window_flist.fits'
+    Parameters
+    ----------
+    rescore : :class:`bool`, optional
+        If `rescore` is ``True``, then write a new file 'window_flist_rescore.fits'
+        rather than over-writing the file 'window_flist.fits'
     """
     #
     # Be certain not to use global calibrations
@@ -251,7 +294,7 @@ def window_score(**kwargs):
         raise PhotoopException(('You have not set the environment variable ' +
                                 'PHOTO_RESOLVE!'))
     filename = os.path.join(resolve_dir, 'window_flist.fits')
-    if 'rescore' in kwargs:
+    if rescore:
         fitsmode = 'readonly'
     else:
         fitsmode = 'update'
@@ -262,8 +305,8 @@ def window_score(**kwargs):
     #
     # Construct the scores filling in the values to FLIST.SCORE
     #
-    flist.field('SCORE')[:] = sdss_score(flist)
-    if 'rescore' in kwargs:
+    flist[1].data['SCORE'][:] = sdss_score(flist)
+    if rescore:
         flist.writeto(os.path.join(resolve_dir, 'window_flist_rescore.fits'))
     flist.close()
     #
