@@ -2,15 +2,16 @@
 # -*- coding: utf-8 -*-
 import warnings
 import json
+import stat
+import sys
 from os import chmod, remove
 from os.path import exists, join
 from shutil import copy, rmtree
 from tempfile import mkdtemp
 from time import sleep
 from collections import OrderedDict
-import six
+import pytest
 import numpy as np
-from astropy.tests.helper import catch_warnings, raises
 from astropy.utils.data import get_pkg_data_filename
 from astropy.table import Table
 from astropy.io.registry import (register_identifier, register_reader,
@@ -30,17 +31,17 @@ class YannyTestCase(object):
     """
     save_temp = False
 
-    def setup(self):
+    def setup_method(self):
         self.temp_dir = mkdtemp(prefix='yanny-test-')
         # Ignore deprecation warnings--this only affects Python 2.5 and 2.6,
         # since deprecation warnings are ignored by defualt on 2.7
-        warnings.simplefilter('ignore')
-        warnings.simplefilter('always', UserWarning)
+        # warnings.simplefilter('ignore')
+        # warnings.simplefilter('always', UserWarning)
         # raise ValueError("I am setting up a subclass of YannyTestCase!")
         with open(get_pkg_data_filename("t/yanny_data.json")) as js:
             self.test_data = json.load(js)
 
-    def teardown(self):
+    def teardown_method(self):
         warnings.resetwarnings()
         if not self.save_temp:
             if hasattr(self, 'temp_dir') and exists(self.temp_dir):
@@ -83,7 +84,11 @@ class YannyTestCase(object):
                 stuff.append(tuple([str(k[0]), str(k[1]), tuple(k[2])]))
             else:
                 stuff.append(tuple([str(k[0]), str(k[1])]))
-        return np.dtype(stuff)
+        d = np.dtype(stuff)
+        if sys.byteorder == 'little':
+            return d
+        else:
+            return d.newbyteorder()
 
 
 class TestYanny(YannyTestCase):
@@ -104,9 +109,9 @@ class TestYanny(YannyTestCase):
         """Test reading to an astropy Table.
         """
         filename = self.data('test_table.par')
-        with raises(PydlutilsException):
+        with pytest.raises(PydlutilsException):
             t = Table.read(filename)
-        with raises(KeyError):
+        with pytest.raises(KeyError):
             t = Table.read(filename, tablename='foo')
         t = Table.read(filename, tablename='test')
         assert isinstance(t.meta, OrderedDict)
@@ -167,11 +172,11 @@ class TestYanny(YannyTestCase):
             status[col[0]] = np.array(table['data'][col[0]], dtype=col[1])
         enums = test_data['enums']
         par = write_ndarray_to_yanny(self.temp('tempfile2.par'),
-                                    (mystruct, status),
-                                    structnames=('magnitudes', 'my_status'),
-                                    enums=enums,
-                                    comments=['This is a test',
-                                    'This is another test'])
+                                     (mystruct, status),
+                                     structnames=('magnitudes', 'my_status'),
+                                     enums=enums,
+                                     comments=['This is a test',
+                                               'This is another test'])
         assert ('typedef enum {\n    FALSE,\n    TRUE\n} BOOLEAN;' in
                 par._symbols['enum'])
         assert 'typedef enum {\n    FAILURE,\n    INCOMPLETE,\n    SUCCESS\n} STATUS;' in par._symbols['enum']
@@ -193,13 +198,13 @@ class TestYanny(YannyTestCase):
         for col in table['dtype']:
             mystruct[col[0]] = np.array(table['data'][col[0]], dtype=col[1])
         enums = {'new_flag': test_data['enums']['new_flag']}
-        with raises(PydlutilsException):
-            par = write_ndarray_to_yanny(self.data('test.par'), mystruct,
-                                        structnames='magnitudes', enums=enums)
-        with raises(PydlutilsException):
-            par = write_ndarray_to_yanny(self.temp('tempfile3.par'), mystruct,
-                                    structnames=('magnitudes', 'my_status'),
-                                    enums=enums)
+        with pytest.raises(PydlutilsException):
+            _ = write_ndarray_to_yanny(self.data('test.par'), mystruct,
+                                       structnames='magnitudes', enums=enums)
+        with pytest.raises(PydlutilsException):
+            _ = write_ndarray_to_yanny(self.temp('tempfile3.par'), mystruct,
+                                       structnames=('magnitudes', 'my_status'),
+                                       enums=enums)
 
     def test_write_ndarray_to_yanny_misc(self):
         """Test other minor features of write_ndarray_to_yanny.
@@ -213,7 +218,7 @@ class TestYanny(YannyTestCase):
         enums = {'new_flag': test_data['enums']['new_flag']}
         hdr = test_data['pairs']
         par = write_ndarray_to_yanny(self.temp('tempfile1.par'), mystruct,
-                                    hdr=hdr, enums=enums)
+                                     hdr=hdr, enums=enums)
         assert 'MYSTRUCT0' in par
         assert par['keyword1'] == hdr['keyword1']
         assert par['keyword2'] == hdr['keyword2']
@@ -226,35 +231,33 @@ class TestYanny(YannyTestCase):
         #
         pair_data = self.test_data["test.par"]["pairs"]
         struct_data = self.test_data["test.par"]["structures"]
-        symbols = [
-"""typedef struct {
+        s1 = """typedef struct {
     float mag[5];
     char b[5][];
     char foo[25];
     double c;
     int flags[2];
     BOOLEAN new_flag;
-} MYSTRUCT;""",
-"""typedef struct {
+} MYSTRUCT;"""
+        s2 = """typedef struct {
     float foo<3>; # This is archaic array notation, strongly deprecated,
     char bar<10>; # but still technically supported.
-} OLD;""",
-"""typedef struct {
+} OLD;"""
+        s3 = """typedef struct {
     STATUS state;
     char timestamp[]; #UTC timestamp in format 2008-06-21T00:27:33
-} STATUS_UPDATE;""",
-            ]
-        enum = [
-"""typedef enum {
+} STATUS_UPDATE;"""
+        symbols = [s1, s2, s3]
+        e1 = """typedef enum {
     FALSE,
     TRUE
-} BOOLEAN;""",
-"""typedef enum {
+} BOOLEAN;"""
+        e2 = """typedef enum {
     FAILURE,
     INCOMPLETE,
     SUCCESS
-} STATUS;""",
-            ]
+} STATUS;"""
+        enum = [e1, e2]
         with open(self.data('test.par')) as f:
             file_data = f.read()
         #
@@ -315,25 +318,25 @@ class TestYanny(YannyTestCase):
         # Test values
         #
         assert np.allclose(par['MYSTRUCT'].mag[0],
-                            np.array([17.5, 17.546, 17.4, 16.1, 16.0]))
+                           np.array([17.5, 17.546, 17.4, 16.1, 16.0]))
         assert np.allclose(par['MYSTRUCT'].mag[5],
-                            np.array([19.3, 18.2, 17.1, 16.0, 15.9]))
-        assert par['MYSTRUCT'].foo[1] == six.b("My dog has no nose.")
+                           np.array([19.3, 18.2, 17.1, 16.0, 15.9]))
+        assert par['MYSTRUCT'].foo[1] == b"My dog has no nose."
         assert np.allclose(par['MYSTRUCT'].c[2], 7.24345567)
         assert (par['MYSTRUCT']['flags'][2] == np.array([123123, 0])).all()
         #
         # Test expected write failures.
         #
         # This should fail, since test.par already exists.
-        with raises(PydlutilsException):
+        with pytest.raises(PydlutilsException):
             par.write()
-        with catch_warnings(PydlutilsUserWarning) as w:
+        with pytest.warns(PydlutilsUserWarning):
             par.append({})
         datatable = {'status_update': {'state': ['SUCCESS', 'SUCCESS'],
-            'timestamp': ['2008-06-22 01:27:33', '2008-06-22 01:27:36']},
-            'new_keyword': 'new_value'}
+                                       'timestamp': ['2008-06-22 01:27:33', '2008-06-22 01:27:36']},
+                     'new_keyword': 'new_value'}
         par.filename = self.temp('test_append.par')
         # This should also fail, because test_append.par does not exist.
-        with raises(PydlutilsException):
+        with pytest.raises(PydlutilsException):
             par.append(datatable)
         return
