@@ -1,6 +1,26 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 # -*- coding: utf-8 -*-
 """This module corresponds to the trace directory in idlutils.
+
+Traceset (or "trace set"):
+    A set of coefficient vectors defining a set of functions
+    over a common independent-variable domain specified by ``xmin``
+    and ``xmax`` values. The functions in the set are defined in
+    terms of a linear combination of basis functions (such as
+    Legendre of Chebyshev polynonials) up to a specified maximum
+    order, weighted by the values in the coefficient vectors, and
+    evaluated using a suitable affine rescaling of the
+    1dependent-variable domain (such as ``[xmin, xmax] -> [-1, 1]``
+    for Legendre polynomials). For evaluation purposes, the
+    domain is assumed by default to be a zero-based integer
+    baseline from ``xmin`` to ``xmax`` such as would correspond to a
+    digital detector pixel grid.
+
+Etymology:
+    From the original motivating use case of encoding the "traces"
+    of multiple spectra across the detector in a multi-fiber spectrograph.
+
+Definition from A. Bolton, U. of Utah, June 2015.
 """
 import numpy as np
 from scipy.special import chebyt
@@ -123,7 +143,7 @@ def fpoly(x, m):
 
 
 def func_fit(x, y, ncoeff, invvar=None, function_name='legendre', ia=None,
-            inputans=None, inputfunc=None):
+             inputans=None, inputfunc=None):
     """Fit `x`, `y` positions to a functional form.
 
     Parameters
@@ -149,7 +169,7 @@ def func_fit(x, y, ncoeff, invvar=None, function_name='legendre', ia=None,
 
     Returns
     -------
-    :func:`tuple` of array-like
+    :class:`tuple` of array-like
         Fit coefficients, length `ncoeff`; fitted values.
 
     Raises
@@ -167,7 +187,7 @@ def func_fit(x, y, ncoeff, invvar=None, function_name='legendre', ia=None,
         if invvar.shape != x.shape:
             raise ValueError('Dimensions of X and invvar do not agree!')
     if ia is None:
-        ia = np.ones((ncoeff,), dtype=np.bool)
+        ia = np.ones((ncoeff,), dtype=bool)
     if not ia.all():
         if inputans is None:
             inputans = np.zeros((ncoeff,), dtype=x.dtype)
@@ -185,16 +205,14 @@ def func_fit(x, y, ncoeff, invvar=None, function_name='legendre', ia=None,
         yfit += y[igood[0]]
     else:
         ncfit = min(ngood, ncoeff)
-        function_map = {
-            'legendre': flegendre,
-            'flegendre': flegendre,
-            'chebyshev': fchebyshev,
-            'fchebyshev': fchebyshev,
-            'chebyshev_split': fchebyshev_split,
-            'fchebyshev_split': fchebyshev_split,
-            'poly': fpoly,
-            'fpoly': fpoly
-            }
+        function_map = {'legendre': flegendre,
+                        'flegendre': flegendre,
+                        'chebyshev': fchebyshev,
+                        'fchebyshev': fchebyshev,
+                        'chebyshev_split': fchebyshev_split,
+                        'fchebyshev_split': fchebyshev_split,
+                        'poly': fpoly,
+                        'fpoly': fpoly}
         try:
             legarr = function_map[function_name](x, ncfit)
         except KeyError:
@@ -217,7 +235,7 @@ def func_fit(x, y, ncoeff, invvar=None, function_name='legendre', ia=None,
         # extra2 = finalarr * np.outer(np.ones((nparams,), dtype=x.dtype),
         #                             (invvar > 0))
         extra2 = finalarr * np.outer(np.ones((nparams,), dtype=x.dtype),
-                                    invvar)
+                                     invvar)
         alpha = np.dot(finalarr, extra2.T)
         # assert alpha.dtype == x.dtype
         if nparams > 1:
@@ -265,8 +283,7 @@ class TraceSet(object):
         When initialized with x,y positions, this contains the fitted y
         values.
     """
-    _func_map = {'poly': fpoly, 'legendre': flegendre,
-                    'chebyshev': fchebyshev}
+    _func_map = {'poly': fpoly, 'legendre': flegendre, 'chebyshev': fchebyshev}
 
     def __init__(self, *args, **kwargs):
         """This class can be initialized either with a set of xy positions,
@@ -326,7 +343,7 @@ class TraceSet(object):
             if 'inmask' in kwargs:
                 inmask = kwargs['inmask']
             else:
-                inmask = np.ones(xpos.shape, dtype=np.bool)
+                inmask = np.ones(xpos.shape, dtype=bool)
             do_jump = False
             if 'xjumplo' in kwargs:
                 do_jump = True
@@ -342,7 +359,7 @@ class TraceSet(object):
             else:
                 self.xjumpval = None
             self.coeff = np.zeros((self.nTrace, self.ncoeff), dtype=xpos.dtype)
-            self.outmask = np.zeros(xpos.shape, dtype=np.bool)
+            self.outmask = np.zeros(xpos.shape, dtype=bool)
             self.yfit = np.zeros(xpos.shape, dtype=xpos.dtype)
             for iTrace in range(self.nTrace):
                 xvec = self.xnorm(xpos[iTrace, :], do_jump)
@@ -353,9 +370,9 @@ class TraceSet(object):
                 thismask = tempivar > 0
                 while (not qdone) and (iIter <= maxiter):
                     res, ycurfit = func_fit(xvec, ypos[iTrace, :], self.ncoeff,
-                        invvar=tempivar, function_name=self.func)
+                                            invvar=tempivar, function_name=self.func)
                     thismask, qdone = djs_reject(ypos[iTrace, :], ycurfit,
-                                                invvar=tempivar)
+                                                 invvar=tempivar)
                     iIter += 1
                 self.yfit[iTrace, :] = ycurfit
                 self.coeff[iTrace, :] = res
@@ -376,7 +393,7 @@ class TraceSet(object):
 
         Returns
         -------
-        :func:`tuple` of array-like
+        :class:`tuple` of array-like
             The x, y positions.
         """
         do_jump = self.has_jump and (not ignore_jump)
@@ -432,7 +449,7 @@ class TraceSet(object):
         if jump:
             # Vector specifying what fraction of the jump has passed:
             jfrac = np.minimum(np.maximum(((xinput - self.xjumplo) /
-                                (self.xjumphi - self.xjumplo)), 0.), 1.)
+                                           (self.xjumphi - self.xjumplo)), 0.), 1.)
             # Conversion to "natural" x baseline:
             xnatural = xinput + jfrac * self.xjumpval
         else:
@@ -455,7 +472,7 @@ def traceset2xy(tset, xpos=None, ignore_jump=False):
 
     Returns
     -------
-    :func:`tuple` of array-like
+    :class:`tuple` of array-like
         The x, y positions.
     """
     return tset.xy(xpos, ignore_jump)
