@@ -1,6 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 # -*- coding: utf-8 -*-
-from __future__ import division
 
 
 def rebin(x, d, sample=False):
@@ -20,7 +19,7 @@ def rebin(x, d, sample=False):
     ----------
     x : :class:`~numpy.ndarray`
         The array to resample.
-    d : :func:`tuple`
+    d : :class:`tuple`
         The new shape of the array.
     sample : :class:`bool`, optional
         If ``True``, nearest-neighbor techniques will be used instead of
@@ -36,18 +35,27 @@ def rebin(x, d, sample=False):
     :exc:`ValueError`
         If the new dimensions are incompatible with the algorithm.
 
+    Warnings
+    --------
+    This function may not be 100% compatible with the IDL version
+    *for integer inputs*. It is not possible at present to examine the details
+    of the IDL code to determine the exact type manipulation that are used.
+    For further discussion see Issue `#60`_.
+
+    .. _`#60`: https://github.com/weaverba137/pydl/issues/60
+
     References
     ----------
-    http://www.harrisgeospatial.com/docs/rebin.html
+    https://www.nv5geospatialsoftware.com/docs/rebin.html
 
     Examples
     --------
-    >>> from numpy import arange, float
+    >>> from numpy import arange, float32
     >>> from pydl import rebin
-    >>> rebin(arange(10, dtype=float), (5,)) # doctest: +NORMALIZE_WHITESPACE
-    array([ 0.5,  2.5,  4.5,  6.5,  8.5])
-    >>> rebin(arange(5, dtype=float), (10,)) # doctest: +NORMALIZE_WHITESPACE
-    array([ 0. ,  0.5,  1. ,  1.5,  2. ,  2.5,  3. ,  3.5,  4. ,  4. ])
+    >>> rebin(arange(10, dtype=float32), (5,)) # doctest: +NORMALIZE_WHITESPACE
+    array([0.5, 2.5, 4.5, 6.5, 8.5], dtype=float32)
+    >>> rebin(arange(5, dtype=float32), (10,)) # doctest: +NORMALIZE_WHITESPACE
+    array([0. , 0.5, 1. , 1.5, 2. , 2.5, 3. , 3.5, 4. , 4. ], dtype=float32)
     """
     from numpy import floor, zeros
     d0 = x.shape
@@ -73,40 +81,44 @@ def rebin(x, d, sample=False):
         sliceobj0 = [slice(None)]*len(d0)
         sliceobj1 = [slice(None)]*len(d0)
         sliceobj = [slice(None)]*len(d)
-        f = d0[k]/d[k]
         if d[k] > d0[k]:
+            f = d0[k]/d[k]
             for i in range(d[k]):
                 p = f*i
                 fp = int(floor(p))
                 sliceobj0[k] = slice(fp, fp + 1)
                 sliceobj[k] = slice(i, i + 1)
                 if sample:
-                    r[sliceobj] = xx[sliceobj0]
+                    r[tuple(sliceobj)] = xx[tuple(sliceobj0)]
                 else:
                     if p < d0[k] - 1:
                         sliceobj1[k] = slice(fp + 1, fp + 2)
-                        rshape = r[sliceobj].shape
-                        r[sliceobj] = (xx[sliceobj0].reshape(rshape) +
-                                       (p - fp)*(xx[sliceobj1] -
-                                                 xx[sliceobj0]).reshape(rshape)
-                                      )
+                        rshape = r[tuple(sliceobj)].shape
+                        r[tuple(sliceobj)] = (xx[tuple(sliceobj0)].reshape(rshape) +
+                                              (p - fp)*(xx[tuple(sliceobj1)] -
+                                                        xx[tuple(sliceobj0)]).reshape(rshape))
                     else:
-                        r[sliceobj] = xx[sliceobj0]
+                        r[tuple(sliceobj)] = xx[tuple(sliceobj0)]
         elif d[k] == d0[k]:
             for i in range(d[k]):
                 sliceobj0[k] = slice(i, i + 1)
                 sliceobj[k] = slice(i, i + 1)
-                r[sliceobj] = xx[sliceobj0]
+                r[tuple(sliceobj)] = xx[tuple(sliceobj0)]
         else:
+            f = d0[k]//d[k]
             for i in range(d[k]):
                 sliceobj[k] = slice(i, i + 1)
                 if sample:
                     fp = int(floor(f*i))
                     sliceobj0[k] = slice(fp, fp + 1)
-                    r[sliceobj] = xx[sliceobj0]
+                    r[tuple(sliceobj)] = xx[tuple(sliceobj0)]
                 else:
                     sliceobj0[k] = slice(int(f*i), int(f*(i+1)))
-                    rshape = r[sliceobj].shape
-                    r[sliceobj] = xx[sliceobj0].sum(k).reshape(rshape)/f
+                    rshape = r[tuple(sliceobj)].shape
+                    rr = xx[tuple(sliceobj0)].sum(k).reshape(rshape)
+                    if xx.dtype.kind == 'u' or xx.dtype.kind == 'i':
+                        r[tuple(sliceobj)] = rr//f
+                    else:
+                        r[tuple(sliceobj)] = rr/f
         xx = r
     return r
