@@ -21,12 +21,9 @@ def smooth(signal, owidth, edge_truncate=False):
     array-like
         A smoothed array with the same dimesions and type as `signal`.
 
-    Notes
-    -----
-
     References
     ----------
-    http://www.exelisvis.com/docs/SMOOTH.html
+    https://www.nv5geospatialsoftware.com/docs/smooth.html
 
     Examples
     --------
